@@ -1,7 +1,7 @@
 
+#include "yacasprivate.h"
 #include "archiver.h"
-#include "../ramscripts/compressedfiles.cpp"
-#include "../ramscripts/minilzo.c"
+#include "minilzo.c"
 
 CCompressedArchive::CCompressedArchive(unsigned char * aBuffer, LispInt aFullSize, LispInt aCompressed)
 : iFiles(aBuffer, aFullSize, aCompressed)
