@@ -1,6 +1,5 @@
 /** \file choices.h switches that control debugging in source code.
  *  Uncomment the defines below to allow a specific type of compilation
- *
  */
 
 #ifndef __choices_h__
@@ -21,18 +20,9 @@
  */
 //#define NO_EXCEPTIONS
 
-
-/** Use Karatsuba multiplication instead of O(n^2) multiplication.
- *  WARNING! This is currently not working and not suggested unless
- *      you want to help debug it.
- */
-//#define USE_KARATSUBA
-
 /** Enable long reference counts. This makes EVERY object 2 bytes
  larger, so use only if needed.
  */
-// #define USE_LONG_REF_COUNTS
-
+#define USE_LONG_REF_COUNTS
 
 #endif
-
