@@ -23,12 +23,12 @@ void LispCleanup::Pop()
 
 void LispCleanup::Delete()
 {
-    iObjects.SetNrItems(0);
+    iObjects.ResizeTo(0);
 }
 
 void LispCleanup::CheckStackEmpty()
 {
-    LISPASSERT(iObjects.NrItems() == 0);
+    LISPASSERT(iObjects.Size() == 0);
 }
 
 void DeletingLispCleanup::Push(LispBase& aObject)
@@ -38,17 +38,17 @@ void DeletingLispCleanup::Push(LispBase& aObject)
 
 void DeletingLispCleanup::Pop()
 {
-    iObjects.SetNrItems(iObjects.NrItems()-1);
+    iObjects.ResizeTo(iObjects.Size()-1);
 }
 
 void DeletingLispCleanup::Delete()
 {
     LispInt i;
-    for (i=iObjects.NrItems()-1;i>=0;i--)
+    for (i=iObjects.Size()-1;i>=0;i--)
     {
         iObjects[i]->Delete();
     }
-    iObjects.SetNrItems(0);
+    iObjects.ResizeTo(0);
 }
 
 
