@@ -18,24 +18,19 @@ void InternalEval(LispEnvironment& aEnvironment, LispPtr& aResult, LispPtr& aExp
 class UserStackInformation : public YacasBase
 {
 public:
-    UserStackInformation():
-        iRulePrecedence(-1),iSide(0)
-    {
+    UserStackInformation()
+      : iOperator(),iExpression(),iRulePrecedence(-1),iSide(0)
 #ifdef YACAS_DEBUG
-        iFileName = "(no file)";
-        iLine = 0;
-#endif
+      , iFileName("(no file)"),iLine(0)
+#endif // YACAS_DEBUG
+    {
     }
     LispPtr iOperator;
     LispPtr iExpression;
     LispInt iRulePrecedence;
     LispInt iSide; // 0=pattern, 1=body
-
-#ifdef YACAS_DEBUG
-    LispCharPtr iFileName;
-    LispInt iLine;
-#endif
-    
+    DBG_( LispChar * iFileName; )
+    DBG_( LispInt iLine; )
 };
 
 /// Abstract evaluator for Lisp expressions.
@@ -45,13 +40,14 @@ public:
 class LispEvaluatorBase : public YacasBase
 {
 public:
-    virtual ~LispEvaluatorBase();
-    virtual void Eval(LispEnvironment& aEnvironment, LispPtr& aResult, LispPtr& aExpression)=0;
-    virtual void ResetStack();
-    virtual UserStackInformation& StackInformation();
-    virtual void ShowStack(LispEnvironment& aEnvironment, LispOutput& aOutput);
+  LispEvaluatorBase() : iBasicInfo() {}
+  virtual ~LispEvaluatorBase();
+  virtual void Eval(LispEnvironment& aEnvironment, LispPtr& aResult, LispPtr& aExpression)=0;
+  virtual void ResetStack();
+  virtual UserStackInformation& StackInformation();
+  virtual void ShowStack(LispEnvironment& aEnvironment, LispOutput& aOutput);
 private:
-    UserStackInformation iBasicInfo;
+  UserStackInformation iBasicInfo;
 };
 
 /// The basic evaluator for Lisp expressions.
@@ -66,7 +62,7 @@ public:
   /// \param aExpression the expression to evaluate.
   ///
   /// First, the evaluation depth is checked. An error is raised if
-  /// the maximum evaluation depth is exceeded. 
+  /// the maximum evaluation depth is exceeded.
   ///
   /// The next step is the actual evaluation. \a aExpression is a
   /// LispObject, so we can distinguish three cases.
@@ -83,20 +79,23 @@ public:
   ///     evaluator is called. Then it is checked agaist the list of
   ///     user function with GetUserFunction() . Again, the
   ///     corresponding evaluator is called if there is a check. If
-  ///     all fails, ReturnUnEvaluated() is called. 
+  ///     all fails, ReturnUnEvaluated() is called.
   ///   - Otherwise (ie. if \a aExpression is a generic object), it is
   ///     copied in \a aResult.
   ///
   /// \note The result of this operation must be a unique (copied)
-  /// element! Eg. its Next might be set... 
+  /// element! Eg. its Next might be set...
   ///
+  /// The LispPtr it can be stored in to is passed in as argument, so it
+  /// does not need to be constructed by the calling environment.
   virtual void Eval(LispEnvironment& aEnvironment, LispPtr& aResult, LispPtr& aExpression);
+  virtual ~BasicEvaluator();
 };
 
 class TracedEvaluator : public BasicEvaluator
 {
 public:
-  TracedEvaluator() :  errorOutput(errorStr){}
+  TracedEvaluator() :  BasicEvaluator(),errorStr(),errorOutput(errorStr){}
   virtual void Eval(LispEnvironment& aEnvironment, LispPtr& aResult, LispPtr& aExpression);
 protected:
   LispString errorStr;
@@ -107,17 +106,17 @@ protected:
 class TracedStackEvaluator : public BasicEvaluator
 {
 public:
-    ~TracedStackEvaluator();
-    virtual void Eval(LispEnvironment& aEnvironment, LispPtr& aResult, LispPtr& aExpression);
-    virtual void ResetStack();
-    virtual UserStackInformation& StackInformation();
-    virtual void ShowStack(LispEnvironment& aEnvironment, LispOutput& aOutput);
-
+  TracedStackEvaluator() : objs() {}
+  virtual ~TracedStackEvaluator();
+  virtual void Eval(LispEnvironment& aEnvironment, LispPtr& aResult, LispPtr& aExpression);
+  virtual void ResetStack();
+  virtual UserStackInformation& StackInformation();
+  virtual void ShowStack(LispEnvironment& aEnvironment, LispOutput& aOutput);
 private:
-    void PushFrame();
-    void PopFrame();
+  void PushFrame();
+  void PopFrame();
 private:
-    CArrayGrower<UserStackInformation*> objs;
+  CArrayGrower<UserStackInformation*, ArrOpsCustomPtr<UserStackInformation> > objs;
 };
 
 
@@ -144,25 +143,25 @@ void ShowExpression(LispString& outString, LispEnvironment& aEnvironment,
 class YacasDebuggerBase : public YacasBase
 {
 public:
-    virtual ~YacasDebuggerBase();
-    virtual void Start() = 0;
-    virtual void Finish() = 0;
-    virtual void Enter(LispEnvironment& aEnvironment, 
-                       LispPtr& aExpression) = 0;
-    virtual void Leave(LispEnvironment& aEnvironment, LispPtr& aResult,
-                       LispPtr& aExpression) = 0;
-    virtual void Error(LispEnvironment& aEnvironment) = 0;
-    virtual LispBoolean Stopped() = 0;
+  virtual ~YacasDebuggerBase();
+  virtual void Start() = 0;
+  virtual void Finish() = 0;
+  virtual void Enter(LispEnvironment& aEnvironment,
+                     LispPtr& aExpression) = 0;
+  virtual void Leave(LispEnvironment& aEnvironment, LispPtr& aResult,
+                     LispPtr& aExpression) = 0;
+  virtual void Error(LispEnvironment& aEnvironment) = 0;
+  virtual LispBoolean Stopped() = 0;
 };
 
 class DefaultDebugger : public YacasDebuggerBase
 {
 public:
-  inline DefaultDebugger(LispPtr& aEnter, LispPtr& aLeave, LispPtr& aError) 
-    : iEnter(aEnter), iLeave(aLeave), iError(aError), iStopped(LispFalse) {};
+  inline DefaultDebugger(LispPtr& aEnter, LispPtr& aLeave, LispPtr& aError)
+    : iEnter(aEnter), iLeave(aLeave), iError(aError), iTopExpr(),iTopResult(),iStopped(LispFalse),defaultEval() {};
   virtual void Start();
   virtual void Finish();
-  virtual void Enter(LispEnvironment& aEnvironment, 
+  virtual void Enter(LispEnvironment& aEnvironment,
                       LispPtr& aExpression);
   virtual void Leave(LispEnvironment& aEnvironment, LispPtr& aResult,
                       LispPtr& aExpression);
