@@ -32,7 +32,7 @@ public:
   LispHashTable() {}
   ~LispHashTable();
   // If string not yet in table, insert. Afterwards return the string.
-  LispString * LookUp(const LispChar * aString, LispBoolean aStringOwnedExternally=LispFalse);
+  LispString * LookUp(const LispChar * aString);
   /// LookUp that takes ownership of the string
   LispString * LookUp(LispString * aString);
   LispString * LookUpCounted(LispChar * aString,LispInt aLength);
