@@ -3,7 +3,7 @@
 #ifndef __patcher_h__
 #define __patcher_h__
 
-void PatchLoad(LispCharPtr aFileContent, LispOutput& aOutput,
+void PatchLoad(LispChar * aFileContent, LispOutput& aOutput,
                LispEnvironment& aEnvironment);
 
 #endif
