@@ -12,21 +12,21 @@
 #include "lisphash.h"
 class LispTokenizer : public YacasBase
 {
-    
 public:
-    /// NextToken returns a string representing the next token,
-    /// or an empty list.
-    virtual LispStringPtr NextToken(LispInput& aInput,
-                                    LispHashTable& aHashTable);
-    virtual ~LispTokenizer(){}
-private:
-    LispString iToken; //Can be used as a token container.
+  LispTokenizer() : iToken() {}
+  /// NextToken returns a string representing the next token,
+  /// or an empty list.
+  virtual LispString * NextToken(LispInput& aInput,
+                                  LispHashTable& aHashTable);
+  virtual ~LispTokenizer(){}
+protected:
+  LispString iToken; //Can be used as a token container.
 };
 
 class CommonLispTokenizer : public LispTokenizer
 {
 public:
-    virtual LispStringPtr NextToken(LispInput& aInput,
+    virtual LispString * NextToken(LispInput& aInput,
                                     LispHashTable& aHashTable);
 };
 
