@@ -18,7 +18,7 @@ static int IsSpace(int c)
 }
 
 
-LispStringPtr XmlTokenizer::NextToken(LispInput& aInput,
+LispString * XmlTokenizer::NextToken(LispInput& aInput,
                                 LispHashTable& aHashTable)
 {
     LispChar c;
@@ -30,7 +30,7 @@ LispStringPtr XmlTokenizer::NextToken(LispInput& aInput,
     //skipping spaces
     while (IsSpace(aInput.Peek())) aInput.Next();
     firstpos = aInput.Position();
-    
+ 
     c = aInput.Next();
     if (c == '<')
     {
